@@ -1,27 +1,15 @@
 /*
- *   Copyright 2010 by Marco MArtin <mart@kde.org>
+    SPDX-FileCopyrightText: 2010 Marco Martin <mart@kde.org>
 
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef DATAMODEL_H
 #define DATAMODEL_H
 
 #include <QAbstractItemModel>
 #include <QJSValue>
+#include <QRegExp>
 #include <QSortFilterProxyModel>
 #include <QVector>
 
@@ -29,9 +17,10 @@
 
 class QTimer;
 
+// All classes here will hopefully be removed in KF6 (along with DataEngines in general)
+
 namespace Plasma
 {
-
 class DataSource;
 class DataModel;
 
@@ -147,7 +136,7 @@ Q_SIGNALS:
 
 protected:
     int roleNameToId(const QString &name) const;
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;    
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
     QHash<int, QByteArray> roleNames() const override;
 
 protected Q_SLOTS:
@@ -175,13 +164,16 @@ class DataModel : public QAbstractItemModel
     Q_PROPERTY(QObject *dataSource READ dataSource WRITE setDataSource)
 
     /**
-     *  It's a regular expression. Only data with keys that match this filter expression will be inserted in the model
+     * It's a regular expression. Only data with keys that match this filter
+     * expression will be inserted in the model
      */
     Q_PROPERTY(QString keyRoleFilter READ keyRoleFilter WRITE setKeyRoleFilter)
 
     /**
-     * it's a regular expression. If the DataSource is connected to more than one source, only inserts data from sources matching this filter expression in the model.
-     * If we want to have a source watch all sources beginning with say "name:", the required regexp would be sourceFilter: "name:.*"
+     * It's a regular expression. If the DataSource is connected to more than one source,
+     * only inserts data from sources matching this filter expression in the model. If we
+     * want to have a source watch all sources beginning with say "name:", the required
+     * regexp would be sourceFilter: "name:.*"
      */
     Q_PROPERTY(QString sourceFilter READ sourceFilter WRITE setSourceFilter)
 
@@ -209,12 +201,10 @@ public:
     void setSourceFilter(const QString &key);
     QString sourceFilter() const;
 
-    //Reimplemented
+    // Reimplemented
     QVariant data(const QModelIndex &index, int role) const override;
-    QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const override;
-    QModelIndex index(int row, int column,
-                      const QModelIndex &parent = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
     QModelIndex parent(const QModelIndex &child) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -252,7 +242,7 @@ private:
     QRegExp m_keyRoleFilterRE;
     QString m_sourceFilter;
     QRegExp m_sourceFilterRE;
-    QMap<QString, QVector<QVariant> > m_items;
+    QMap<QString, QVector<QVariant>> m_items;
     QHash<int, QByteArray> m_roleNames;
     QHash<QString, int> m_roleIds;
     int m_maxRoleId;
@@ -261,7 +251,7 @@ private:
 int DataModel::countItems() const
 {
     int count = 0;
-    foreach (const QVector<QVariant> &v, m_items) {
+    for (const QVector<QVariant> &v : qAsConst(m_items)) {
         count += v.count();
     }
     return count;
