@@ -9,16 +9,15 @@
 #ifndef PLASMA_APPLET_H
 #define PLASMA_APPLET_H
 
-#include <QObject>
 #include <QKeySequence>
+#include <QObject>
 #include <QUrl>
 
 #include <KConfigGroup>
 #include <KPluginInfo>
 
-#include <plasma/plasma.h>
-#include <plasma/version.h>
 #include <plasma/framesvg.h>
+#include <plasma/plasma.h>
 
 #include <KPackage/Package>
 
@@ -27,7 +26,6 @@ class KConfigLoader;
 
 namespace Plasma
 {
-
 class AppletPrivate;
 class Containment;
 class DataEngine;
@@ -58,6 +56,7 @@ class PLASMA_EXPORT Applet : public QObject
     Q_PROPERTY(Plasma::Types::ImmutabilityType immutability READ immutability WRITE setImmutability NOTIFY immutabilityChanged)
     Q_PROPERTY(Plasma::Types::FormFactor formFactor READ formFactor NOTIFY formFactorChanged)
     Q_PROPERTY(Plasma::Types::Location location READ location NOTIFY locationChanged)
+    Q_PROPERTY(Plasma::Types::ContainmentDisplayHints containmentDisplayHints READ containmentDisplayHints NOTIFY containmentDisplayHintsChanged)
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged FINAL)
     Q_PROPERTY(QString icon READ icon WRITE setIcon NOTIFY iconChanged FINAL)
     Q_PROPERTY(bool busy READ isBusy WRITE setBusy NOTIFY busyChanged FINAL)
@@ -78,7 +77,7 @@ class PLASMA_EXPORT Applet : public QObject
     Q_PROPERTY(Plasma::Types::BackgroundHints effectiveBackgroundHints READ effectiveBackgroundHints NOTIFY effectiveBackgroundHintsChanged FINAL)
 
 public:
-//CONSTRUCTORS
+    // CONSTRUCTORS
     /**
      * @param parent the QObject this applet is parented to
      * @param serviceId the name of the .desktop file containing the
@@ -113,7 +112,7 @@ public:
 
     ~Applet() override;
 
-//BOOKKEEPING
+    // BOOKKEEPING
     /**
      * @return the id of this applet
      */
@@ -175,14 +174,20 @@ public:
      */
     Types::Location location() const;
 
-//CONFIGURATION
     /**
-    * Returns the KConfigGroup to access the applets configuration.
-    *
-    * This config object will write to an instance
-    * specific config file named \<appletname\>\<instanceid\>rc
-    * in the Plasma appdata directory.
-    **/
+     * @return Display hints that come from the containment that suggest the applet how to look and behave.
+     * @since 5.77
+     */
+    Types::ContainmentDisplayHints containmentDisplayHints() const;
+
+    // CONFIGURATION
+    /**
+     * Returns the KConfigGroup to access the applets configuration.
+     *
+     * This config object will write to an instance
+     * specific config file named \<appletname\>\<instanceid\>rc
+     * in the Plasma appdata directory.
+     **/
     KConfigGroup config() const;
 
     /**
@@ -206,7 +211,7 @@ public:
      * Saves state information about this applet that will
      * be accessed when next instantiated in the restore(KConfigGroup&) method.
      *
-     * This method does not need to be reimplmented by Applet
+     * This method does not need to be reimplemented by Applet
      * subclasses, but can be useful for Applet specializations
      * (such as Containment) to do so.
      *
@@ -218,7 +223,7 @@ public:
      * Restores state information about this applet saved previously
      * in save(KConfigGroup&).
      *
-     * This method does not need to be reimplmented by Applet
+     * This method does not need to be reimplemented by Applet
      * subclasses, but can be useful for Applet specializations
      * (such as Containment) to do so.
      **/
@@ -252,7 +257,7 @@ public:
      */
     void setUserConfiguring(bool configuring);
 
-//UTILS
+// UTILS
 #if PLASMA_ENABLE_DEPRECATED_SINCE(5, 6)
     /**
      * Accessor for the associated Package object if any.
@@ -283,7 +288,7 @@ public:
      */
     void updateConstraints(Plasma::Types::Constraints constraints = Plasma::Types::AllConstraints);
 
-//METADATA
+// METADATA
 #if PLASMA_ENABLE_DEPRECATED_SINCE(5, 28)
     /**
      * @return metadata information about this plugin
@@ -399,12 +404,13 @@ public:
     void setUserBackgroundHints(Plasma::Types::BackgroundHints hint);
 
     /**
-     * The effective background hints the applet will have: it will follow userBackgroundHints only if backgroundHints has the Plasma::Types::ConfigurableBackground flag set
+     * The effective background hints the applet will have: it will follow userBackgroundHints only if backgroundHints has the
+     * Plasma::Types::ConfigurableBackground flag set
      * @since 5.65
      */
     Plasma::Types::BackgroundHints effectiveBackgroundHints() const;
 
-//ACTIONS
+    // ACTIONS
     /**
      * Returns a list of context-related QAction instances.
      *
@@ -432,7 +438,7 @@ public:
      */
     QKeySequence globalShortcut() const;
 
-// ASSOCIATED APPLICATION
+    // ASSOCIATED APPLICATION
     /**
      * Sets an application associated to this applet, that will be
      * regarded as a full view of what is represented in the applet
@@ -473,14 +479,14 @@ public:
      */
     bool hasValidAssociatedApplication() const;
 
-//Completely UI-specific, remove or move to scriptengine
+    // Completely UI-specific, remove or move to scriptengine
     /**
      * @return true if this plasmoid provides a GUI configuration
      **/
     bool hasConfigurationInterface() const;
 
 Q_SIGNALS:
-//BOOKEEPING
+    // BOOKKEEPING
     /**
      * Emitted when the immutability changes
      * @since 4.4
@@ -536,7 +542,7 @@ Q_SIGNALS:
      */
     void effectiveBackgroundHintsChanged();
 
-//CONFIGURATION
+    // CONFIGURATION
     /**
      * Emitted when an applet has changed values in its configuration
      * and wishes for them to be saved at the next save point. As this implies
@@ -552,7 +558,7 @@ Q_SIGNALS:
      */
     void userConfiguringChanged(bool configuring);
 
-//ACTIONS
+    // ACTIONS
     /**
      * Emitted just before the contextual actions are about to show
      * For instance just before the context menu containing the actions
@@ -566,7 +572,7 @@ Q_SIGNALS:
      */
     void activated();
 
-//TODO: fix usage in containment, port to QObject::destroyed
+    // TODO: fix usage in containment, port to QObject::destroyed
     /**
      * Emitted when the applet is deleted
      */
@@ -582,6 +588,8 @@ Q_SIGNALS:
      */
     void locationChanged(Plasma::Types::Location location);
 
+    void containmentDisplayHintsChanged(Plasma::Types::ContainmentDisplayHints hints);
+
     /**
      * Emitted when setConfigurationRequired was called
      * @see setConfigurationRequired
@@ -590,7 +598,7 @@ Q_SIGNALS:
     void configurationRequiredChanged(bool needsConfig, const QString &reason);
 
 public Q_SLOTS:
-//BOOKKEEPING
+    // BOOKKEEPING
     /**
      * Call this method when the applet fails to launch properly. An
      * optional reason can be provided.
@@ -626,14 +634,14 @@ public Q_SLOTS:
      */
     void setStatus(const Types::ItemStatus stat);
 
-//CONFIGURATION
+    // CONFIGURATION
     /**
      * Called when applet configuration values have changed.
      */
-    //TODO KF6: make it not a slot anymore and protected
+    // TODO KF6: make it not a slot anymore and protected
     virtual void configChanged();
 
-//UTILS
+    // UTILS
     /**
      * Sends all pending constraints updates to the applet. Will usually
      * be called automatically, but can also be called manually if needed.
@@ -652,19 +660,19 @@ public Q_SLOTS:
      **/
     virtual void init();
 
-//ASSOCIATED APPLICATION
+    // ASSOCIATED APPLICATION
     /**
-    * Open the application associated to this applet, if it's not set
-    * but some urls are, open those urls with the proper application
-    * for their mimetype
-    * @see setAssociatedApplication()
-    * @see setAssociatedApplicationUrls()
-    * @since 4.4
-    */
+     * Open the application associated to this applet, if it's not set
+     * but some urls are, open those urls with the proper application
+     * for their mimetype
+     * @see setAssociatedApplication()
+     * @see setAssociatedApplicationUrls()
+     * @since 4.4
+     */
     void runAssociatedApplication();
 
 protected:
-//CONSTRUCTORS
+    // CONSTRUCTORS
     /**
      * This constructor is to be used with the plugin loading systems
      * found in KPluginInfo and KService. The argument list is expected
@@ -677,7 +685,7 @@ protected:
      */
     Applet(QObject *parent, const QVariantList &args);
 
-//CONFIGURATION
+    // CONFIGURATION
     /**
      * When called, the Applet should write any information needed as part
      * of the Applet's running state to the configuration object in config()
@@ -713,7 +721,7 @@ protected:
      */
     void setConfigurationRequired(bool needsConfiguring, const QString &reason = QString());
 
-//UTILS
+    // UTILS
     /**
      * Called when any of the constraints for the applet have been updated. These constraints
      * range from notifying when the applet has officially "started up" to when geometry changes
@@ -734,7 +742,7 @@ protected:
      */
     virtual void constraintsEvent(Plasma::Types::Constraints constraints);
 
-//TODO: timerEvent should go into AppletPrivate
+    // TODO: timerEvent should go into AppletPrivate
     /**
      * Reimplemented from QObject
      */
@@ -760,7 +768,7 @@ private:
 
     AppletPrivate *const d;
 
-    //Corona needs to access setLaunchErrorMessage and init
+    // Corona needs to access setLaunchErrorMessage and init
     friend class Corona;
     friend class CoronaPrivate;
     friend class Containment;
@@ -778,12 +786,12 @@ private:
 /**
  * Register an applet when it is contained in a loadable module
  */
+/* clang-format off */
 #define K_EXPORT_PLASMA_APPLET(libname, classname) \
-    K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-    K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+    K_PLUGIN_FACTORY(factory, registerPlugin<classname>();)
 
 #define K_EXPORT_PLASMA_APPLET_WITH_JSON(libname, classname, jsonFile) \
-    K_PLUGIN_FACTORY_WITH_JSON(factory, jsonFile, registerPlugin<classname>();) \
-    K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+    K_PLUGIN_FACTORY_WITH_JSON(factory, jsonFile, registerPlugin<classname>();)
+/* clang-format on */
 
 #endif // multiple inclusion guard
