@@ -1,60 +1,47 @@
 /*
- *   Copyright 2006-2007 Aaron Seigo <aseigo@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2006-2007 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "dataengine.h"
-#include "private/dataengine_p.h"
 #include "private/datacontainer_p.h"
+#include "private/dataengine_p.h"
 
 #include <QAbstractItemModel>
 #include <QQueue>
-#include <QTimer>
 #include <QTime>
+#include <QTimer>
 #include <QTimerEvent>
 #include <QVariant>
 
 #include <QDebug>
 #include <QStandardPaths>
 
-#include <kplugininfo.h>
-#include <kservice.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include "datacontainer.h"
 #include "package.h"
 #include "pluginloader.h"
-#include "service.h"
 #include "scripting/dataenginescript.h"
+#include "service.h"
 
+#include "config-plasma.h"
 #include "private/service_p.h"
 #include "private/storage_p.h"
-#include "config-plasma.h"
 
 namespace Plasma
 {
-
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 67)
 DataEngine::DataEngine(const KPluginInfo &plugin, QObject *parent)
     : DataEngine(plugin.toMetaData(), parent)
-{}
+{
+}
+#endif
 
 DataEngine::DataEngine(const KPluginMetaData &plugin, QObject *parent)
-    : QObject(parent),
-      d(new DataEnginePrivate(this, plugin))
+    : QObject(parent)
+    , d(new DataEnginePrivate(this, plugin))
 {
     if (d->script) {
         d->setupScriptSupport();
@@ -66,8 +53,8 @@ DataEngine::DataEngine(const KPluginMetaData &plugin, QObject *parent)
 }
 
 DataEngine::DataEngine(QObject *parent, const QVariantList &args)
-    : QObject(parent),
-      d(new DataEnginePrivate(this, KPluginInfo(args).toMetaData(), args))
+    : QObject(parent)
+    , d(new DataEnginePrivate(this, KPluginInfo(args).toMetaData(), args))
 {
     if (d->script) {
         d->setupScriptSupport();
@@ -77,7 +64,7 @@ DataEngine::DataEngine(QObject *parent, const QVariantList &args)
 
 DataEngine::~DataEngine()
 {
-    //qCDebug(LOG_PLASMA) << objectName() << ": bye bye birdy! ";
+    // qCDebug(LOG_PLASMA) << objectName() << ": bye bye birdy! ";
     delete d;
 }
 
@@ -102,40 +89,38 @@ Service *DataEngine::serviceForSource(const QString &source)
     return new NullService(source, this);
 }
 
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 67)
 KPluginInfo DataEngine::pluginInfo() const
 {
     return KPluginInfo(d->dataEngineDescription);
 }
+#endif
 
 KPluginMetaData DataEngine::metadata() const
 {
     return d->dataEngineDescription;
 }
 
-void DataEngine::connectSource(const QString &source, QObject *visualization,
-                               uint pollingInterval,
-                               Plasma::Types::IntervalAlignment intervalAlignment) const
+void DataEngine::connectSource(const QString &source, QObject *visualization, uint pollingInterval, Plasma::Types::IntervalAlignment intervalAlignment) const
 {
-    //qCDebug(LOG_PLASMA) << "connectSource" << source;
+    // qCDebug(LOG_PLASMA) << "connectSource" << source;
     bool newSource;
     DataContainer *s = d->requestSource(source, &newSource);
 
     if (s) {
         // we suppress the immediate invocation of dataUpdated here if the
-        // source was prexisting and they don't request delayed updates
+        // source was preexisting and they don't request delayed updates
         // (we want to do an immediate update in that case so they don't
         // have to wait for the first time out)
         if (newSource && !s->data().isEmpty()) {
             newSource = false;
         }
-        d->connectSource(s, visualization, pollingInterval, intervalAlignment,
-                         !newSource || pollingInterval > 0);
-        //qCDebug(LOG_PLASMA) << " ==> source connected";
+        d->connectSource(s, visualization, pollingInterval, intervalAlignment, !newSource || pollingInterval > 0);
+        // qCDebug(LOG_PLASMA) << " ==> source connected";
     }
 }
 
-void DataEngine::connectAllSources(QObject *visualization, uint pollingInterval,
-                                   Plasma::Types::IntervalAlignment intervalAlignment) const
+void DataEngine::connectAllSources(QObject *visualization, uint pollingInterval, Plasma::Types::IntervalAlignment intervalAlignment) const
 {
     for (DataContainer *s : qAsConst(d->sources)) {
         d->connectSource(s, visualization, pollingInterval, intervalAlignment);
@@ -170,8 +155,8 @@ bool DataEngine::updateSourceEvent(const QString &source)
     if (d->script) {
         return d->script->updateSourceEvent(source);
     } else {
-        //qCDebug(LOG_PLASMA) << source;
-        return false; //TODO: should this be true to trigger, even needless, updates on every tick?
+        // qCDebug(LOG_PLASMA) << source;
+        return false; // TODO: should this be true to trigger, even needless, updates on every tick?
     }
 }
 
@@ -192,7 +177,7 @@ void DataEngine::setData(const QString &source, const QString &key, const QVaria
     s->setData(key, value);
 
     if (isNew && source != d->waitingSourceRequest) {
-        emit sourceAdded(source);
+        Q_EMIT sourceAdded(source);
     }
 
     d->scheduleSourcesUpdated();
@@ -214,7 +199,7 @@ void DataEngine::setData(const QString &source, const QVariantMap &data)
     }
 
     if (isNew && source != d->waitingSourceRequest) {
-        emit sourceAdded(source);
+        Q_EMIT sourceAdded(source);
     }
 
     d->scheduleSourcesUpdated();
@@ -273,11 +258,10 @@ void DataEngine::addSource(DataContainer *source)
         return;
     }
 
-    QObject::connect(source, SIGNAL(updateRequested(DataContainer*)),
-                     this, SLOT(internalUpdateSource(DataContainer*)));
-    QObject::connect(source, SIGNAL(destroyed(QObject*)), this, SLOT(sourceDestroyed(QObject*)));
+    QObject::connect(source, SIGNAL(updateRequested(DataContainer *)), this, SLOT(internalUpdateSource(DataContainer *)));
+    QObject::connect(source, SIGNAL(destroyed(QObject *)), this, SLOT(sourceDestroyed(QObject *)));
     d->sources.insert(source->objectName(), source);
-    emit sourceAdded(source->objectName());
+    Q_EMIT sourceAdded(source->objectName());
     d->scheduleSourcesUpdated();
 }
 
@@ -307,10 +291,10 @@ void DataEngine::removeSource(const QString &source)
     if (it != d->sources.end()) {
         DataContainer *s = it.value();
         s->d->store();
+        Q_EMIT sourceRemoved(source);
         d->sources.erase(it);
         s->disconnect(this);
         s->deleteLater();
-        emit sourceRemoved(source);
     }
 }
 
@@ -321,10 +305,10 @@ void DataEngine::removeAllSources()
         it.next();
         Plasma::DataContainer *s = it.value();
         const QString source = it.key();
+        Q_EMIT sourceRemoved(source);
         it.remove();
         s->disconnect(this);
         s->deleteLater();
-        emit sourceRemoved(source);
     }
 }
 
@@ -350,17 +334,17 @@ QHash<QString, DataContainer *> DataEngine::containerDict() const
 
 void DataEngine::timerEvent(QTimerEvent *event)
 {
-    //qCDebug(LOG_PLASMA);
+    // qCDebug(LOG_PLASMA);
     if (event->timerId() == d->updateTimerId) {
         // if the freq update is less than 0, don't bother
         if (d->minPollingInterval < 0) {
-            //qCDebug(LOG_PLASMA) << "uh oh.. no polling allowed!";
+            // qCDebug(LOG_PLASMA) << "uh oh.. no polling allowed!";
             return;
         }
 
         // minPollingInterval
         if (d->updateTimer.elapsed() < d->minPollingInterval) {
-            //qCDebug(LOG_PLASMA) << "hey now.. slow down!";
+            // qCDebug(LOG_PLASMA) << "hey now.. slow down!";
             return;
         }
 
@@ -385,7 +369,7 @@ void DataEngine::updateAllSources()
     QHashIterator<QString, Plasma::DataContainer *> it(d->sources);
     while (it.hasNext()) {
         it.next();
-        //qCDebug(LOG_PLASMA) << "updating" << it.key();
+        // qCDebug(LOG_PLASMA) << "updating" << it.key();
         if (it.value()->isUsed()) {
             updateSourceEvent(it.key());
         }
@@ -402,11 +386,12 @@ void DataEngine::forceImmediateUpdateOfAllVisualizations()
         }
     }
 }
-
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
 Package DataEngine::package() const
 {
     return d->package ? *d->package : Package();
 }
+#endif
 
 void DataEngine::setStorageEnabled(const QString &source, bool store)
 {
@@ -418,15 +403,14 @@ void DataEngine::setStorageEnabled(const QString &source, bool store)
 
 // Private class implementations
 DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginMetaData &md, const QVariantList &args)
-    : q(e),
-      dataEngineDescription(md),
-      refCount(-1), // first ref
-      checkSourcesTimerId(0),
-      updateTimerId(0),
-      minPollingInterval(-1),
-      valid(false),
-      script(nullptr),
-      package(nullptr)
+    : q(e)
+    , dataEngineDescription(md)
+    , refCount(-1)
+    , checkSourcesTimerId(0) // first ref
+    , updateTimerId(0)
+    , minPollingInterval(-1)
+    , valid(false)
+    , script(nullptr)
 {
     updateTimer.start();
 
@@ -436,13 +420,14 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginMetaData &md, c
     }
 
     if (dataEngineDescription.isValid()) {
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
+
         QString api = dataEngineDescription.value(QStringLiteral("X-Plasma-API"));
 
         if (!api.isEmpty()) {
-            const QString path =
-                QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                       QStringLiteral(PLASMA_RELATIVE_DATA_INSTALL_DIR "/dataengines/") + dataEngineDescription.pluginId(),
-                                       QStandardPaths::LocateDirectory);
+            const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                        QStringLiteral(PLASMA_RELATIVE_DATA_INSTALL_DIR "/dataengines/") + dataEngineDescription.pluginId(),
+                                                        QStandardPaths::LocateDirectory);
             package = new Package(PluginLoader::self()->loadPackage(QStringLiteral("Plasma/DataEngine"), api));
             package->setPath(path);
 
@@ -459,6 +444,7 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginMetaData &md, c
                 package = nullptr;
             }
         }
+#endif
     }
 }
 
@@ -466,31 +452,32 @@ DataEnginePrivate::~DataEnginePrivate()
 {
     delete script;
     script = nullptr;
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
     delete package;
     package = nullptr;
+#endif
 }
 
 void DataEnginePrivate::internalUpdateSource(DataContainer *source)
 {
-    if (minPollingInterval > 0 &&
-            source->timeSinceLastUpdate() < (uint)minPollingInterval) {
+    if (minPollingInterval > 0 && source->timeSinceLastUpdate() < (uint)minPollingInterval) {
         // skip updating this source; it's been too soon
-        //qCDebug(LOG_PLASMA) << "internal update source is delaying" << source->timeSinceLastUpdate() << minPollingInterval;
-        //but fake an update so that the signalrelay that triggered this gets the data from the
-        //recent update. this way we don't have to worry about queuing - the relay will send a
-        //signal immediately and everyone else is undisturbed.
+        // qCDebug(LOG_PLASMA) << "internal update source is delaying" << source->timeSinceLastUpdate() << minPollingInterval;
+        // but fake an update so that the signalrelay that triggered this gets the data from the
+        // recent update. this way we don't have to worry about queuing - the relay will send a
+        // signal immediately and everyone else is undisturbed.
         source->setNeedsUpdate();
         return;
     }
 
     if (q->updateSourceEvent(source->objectName())) {
-        //qCDebug(LOG_PLASMA) << "queuing an update";
+        // qCDebug(LOG_PLASMA) << "queuing an update";
         scheduleSourcesUpdated();
-    }/* else {
-#ifndef NDEBUG
-        // qCDebug(LOG_PLASMA) << "no update";
-#endif
-    }*/
+    } /* else {
+ #ifndef NDEBUG
+         // qCDebug(LOG_PLASMA) << "no update";
+ #endif
+     }*/
 }
 
 void DataEnginePrivate::ref()
@@ -520,23 +507,23 @@ DataContainer *DataEnginePrivate::source(const QString &sourceName, bool createW
         return nullptr;
     }
 
-    //qCDebug(LOG_PLASMA) << "DataEngine " << q->objectName() << ": could not find DataContainer " << sourceName << ", creating";
+    // qCDebug(LOG_PLASMA) << "DataEngine " << q->objectName() << ": could not find DataContainer " << sourceName << ", creating";
     DataContainer *s = new DataContainer(q);
     s->setObjectName(sourceName);
     sources.insert(sourceName, s);
-    QObject::connect(s, SIGNAL(destroyed(QObject*)), q, SLOT(sourceDestroyed(QObject*)));
-    QObject::connect(s, SIGNAL(updateRequested(DataContainer*)),
-                     q, SLOT(internalUpdateSource(DataContainer*)));
+    QObject::connect(s, SIGNAL(destroyed(QObject *)), q, SLOT(sourceDestroyed(QObject *)));
+    QObject::connect(s, SIGNAL(updateRequested(DataContainer *)), q, SLOT(internalUpdateSource(DataContainer *)));
 
     return s;
 }
 
-void DataEnginePrivate::connectSource(DataContainer *s, QObject *visualization,
+void DataEnginePrivate::connectSource(DataContainer *s,
+                                      QObject *visualization,
                                       uint pollingInterval,
                                       Plasma::Types::IntervalAlignment align,
                                       bool immediateCall)
 {
-    //qCDebug(LOG_PLASMA) << "connect source called" << s->objectName() << "with interval" << pollingInterval;
+    // qCDebug(LOG_PLASMA) << "connect source called" << s->objectName() << "with interval" << pollingInterval;
 
     if (pollingInterval > 0) {
         // never more frequently than allowed, never more than 20 times per second
@@ -550,21 +537,16 @@ void DataEnginePrivate::connectSource(DataContainer *s, QObject *visualization,
     if (immediateCall) {
         // we don't want to do an immediate call if we are simply
         // reconnecting
-        //qCDebug(LOG_PLASMA) << "immediate call requested, we have:" << s->visualizationIsConnected(visualization);
-        immediateCall = !s->data().isEmpty() &&
-                        !s->visualizationIsConnected(visualization);
+        // qCDebug(LOG_PLASMA) << "immediate call requested, we have:" << s->visualizationIsConnected(visualization);
+        immediateCall = !s->data().isEmpty() && !s->visualizationIsConnected(visualization);
     }
 
     s->connectVisualization(visualization, pollingInterval, align);
 
     if (immediateCall) {
-        QMetaObject::invokeMethod(visualization, "dataUpdated",
-                                  Q_ARG(QString, s->objectName()),
-                                  Q_ARG(Plasma::DataEngine::Data, s->data()));
+        QMetaObject::invokeMethod(visualization, "dataUpdated", Q_ARG(QString, s->objectName()), Q_ARG(Plasma::DataEngine::Data, s->data()));
         if (s->d->model) {
-            QMetaObject::invokeMethod(visualization, "modelChanged",
-                                      Q_ARG(QString, s->objectName()),
-                                      Q_ARG(QAbstractItemModel*, s->d->model.data()));
+            QMetaObject::invokeMethod(visualization, "modelChanged", Q_ARG(QString, s->objectName()), Q_ARG(QAbstractItemModel *, s->d->model.data()));
         }
         s->d->dirty = false;
     }
@@ -576,7 +558,7 @@ void DataEnginePrivate::sourceDestroyed(QObject *object)
     while (it != sources.end()) {
         if (it.value() == object) {
             sources.erase(it);
-            emit q->sourceRemoved(object->objectName());
+            Q_EMIT q->sourceRemoved(object->objectName());
             break;
         }
         ++it;
@@ -589,7 +571,7 @@ DataContainer *DataEnginePrivate::requestSource(const QString &sourceName, bool
         *newSource = false;
     }
 
-    //qCDebug(LOG_PLASMA) << "requesting source " << sourceName;
+    // qCDebug(LOG_PLASMA) << "requesting source " << sourceName;
     DataContainer *s = source(sourceName, false);
 
     if (!s) {
@@ -607,7 +589,7 @@ DataContainer *DataEnginePrivate::requestSource(const QString &sourceName, bool
                     *newSource = true;
                 }
                 QObject::connect(s, &DataContainer::becameUnused, q, &DataEngine::removeSource);
-                emit q->sourceAdded(sourceName);
+                Q_EMIT q->sourceAdded(sourceName);
             }
         }
         waitingSourceRequest.clear();
@@ -620,10 +602,6 @@ DataContainer *DataEnginePrivate::requestSource(const QString &sourceName, bool
 // package exists and that we have a script engine
 void DataEnginePrivate::setupScriptSupport()
 {
-    if (!package) {
-        return;
-    }
-
     /*
     #ifndef NDEBUG
     // qCDebug(LOG_PLASMA) << "sletting up script support, package is in" << package->path()
