@@ -9,34 +9,33 @@
 
 #include "private/containment_p.h"
 
-#include <QDebug>
 #include <KLocalizedString>
 #include <KWindowSystem>
+#include <QDebug>
 
 #include "config-plasma.h"
 
 #include "pluginloader.h"
 
+#include "debug_p.h"
 #include "private/applet_p.h"
 #include "timetracker.h"
-#include "debug_p.h"
 
 namespace Plasma
 {
-
 const char ContainmentPrivate::defaultWallpaper[] = "org.kde.image";
 
-ContainmentPrivate::ContainmentPrivate(Containment *c):
-    q(c),
-    formFactor(Types::Planar),
-    location(Types::Floating),
-    lastScreen(-1), // never had a screen
-    type(Plasma::Types::NoContainmentType),
-    uiReady(false),
-    appletsUiReady(false)
+ContainmentPrivate::ContainmentPrivate(Containment *c)
+    : q(c)
+    , formFactor(Types::Planar)
+    , location(Types::Floating)
+    , lastScreen(-1)
+    , type(Plasma::Types::NoContainmentType) // never had a screen
+    , uiReady(false)
+    , appletsUiReady(false)
 {
-    //if the parent is an applet (i.e we are the systray)
-    //we want to follow screen changed signals from the parent's containment
+    // if the parent is an applet (i.e we are the systray)
+    // we want to follow screen changed signals from the parent's containment
     auto appletParent = qobject_cast<Plasma::Applet *>(c->parent());
     if (appletParent) {
         QObject::connect(appletParent->containment(), &Containment::screenChanged, c, &Containment::screenChanged);
@@ -48,14 +47,13 @@ Plasma::ContainmentPrivate::~ContainmentPrivate()
     applets.clear();
 }
 
-
 void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containment *c)
 {
     actions->setConfigGroup(QStringLiteral("Shortcuts-Containment"));
 
-    //adjust applet actions
+    // adjust applet actions
     QAction *appAction = qobject_cast<QAction *>(actions->action(QStringLiteral("remove")));
-    appAction->setShortcut(QKeySequence(Qt::ALT+Qt::Key_D, Qt::ALT+Qt::Key_R));
+    appAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D, Qt::ALT + Qt::Key_R));
     if (c && c->d->isPanelContainment()) {
         appAction->setText(i18n("Remove this Panel"));
     } else {
@@ -64,16 +62,16 @@ void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containme
 
     appAction = qobject_cast<QAction *>(actions->action(QStringLiteral("configure")));
     if (appAction) {
-        appAction->setShortcut(QKeySequence(Qt::ALT+Qt::Key_D, Qt::ALT+Qt::Key_S));
+        appAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D, Qt::ALT + Qt::Key_S));
         appAction->setText(i18n("Activity Settings"));
     }
 
-    //add our own actions
+    // add our own actions
     QAction *appletBrowserAction = actions->add<QAction>(QStringLiteral("add widgets"));
     appletBrowserAction->setAutoRepeat(false);
     appletBrowserAction->setText(i18n("Add Widgets..."));
     appletBrowserAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
-    appletBrowserAction->setShortcut(QKeySequence(Qt::ALT+Qt::Key_D, Qt::Key_A));
+    appletBrowserAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D, Qt::Key_A));
     appletBrowserAction->setData(Plasma::Types::AddAction);
 }
 
@@ -91,7 +89,7 @@ void ContainmentPrivate::configChanged()
 
 void ContainmentPrivate::checkStatus(Plasma::Types::ItemStatus appletStatus)
 {
-    //qCDebug(LOG_PLASMA) << "================== "<< appletStatus << q->status();
+    // qCDebug(LOG_PLASMA) << "================== "<< appletStatus << q->status();
     if (appletStatus == q->status()) {
         return;
     }
@@ -113,7 +111,7 @@ void ContainmentPrivate::checkStatus(Plasma::Types::ItemStatus appletStatus)
 
 void ContainmentPrivate::triggerShowAddWidgets()
 {
-    emit q->showAddWidgetsInterface(QPointF());
+    Q_EMIT q->showAddWidgetsInterface(QPointF());
 }
 
 void ContainmentPrivate::containmentConstraintsEvent(Plasma::Types::Constraints constraints)
@@ -122,9 +120,9 @@ void ContainmentPrivate::containmentConstraintsEvent(Plasma::Types::Constraints
         return;
     }
 
-    //qCDebug(LOG_PLASMA) << "got containmentConstraintsEvent" << constraints;
+    // qCDebug(LOG_PLASMA) << "got containmentConstraintsEvent" << constraints;
     if (constraints & Plasma::Types::ImmutableConstraint) {
-        //update actions
+        // update actions
         const bool unlocked = q->immutability() == Types::Mutable;
 
         QAction *action = q->actions()->action(QStringLiteral("remove"));
@@ -191,7 +189,7 @@ Applet *ContainmentPrivate::createApplet(const QString &name, const QVariantList
     }
 
     q->addApplet(applet);
-    //mirror behavior of resorecontents: if an applet is not valid, set it immediately to uiReady
+    // mirror behavior of resorecontents: if an applet is not valid, set it immediately to uiReady
     if (!applet->pluginMetaData().isValid()) {
         applet->updateConstraints(Plasma::Types::UiReadyConstraint);
     }
@@ -202,8 +200,8 @@ void ContainmentPrivate::appletDeleted(Plasma::Applet *applet)
 {
     applets.removeAll(applet);
 
-    emit q->appletRemoved(applet);
-    emit q->configNeedsSaving();
+    Q_EMIT q->appletRemoved(applet);
+    Q_EMIT q->configNeedsSaving();
 }
 
 bool ContainmentPrivate::isPanelContainment() const
@@ -217,30 +215,30 @@ void ContainmentPrivate::setStarted()
         q->Applet::d->started = true;
 
         if (uiReady) {
-            emit q->uiReadyChanged(true);
+            Q_EMIT q->uiReadyChanged(true);
         }
     }
 }
 
 void ContainmentPrivate::setUiReady()
 {
-    //if we are the containment and there is still some uncomplete applet, we're still incomplete
+    // if we are the containment and there is still some incomplete applet, we're still incomplete
     if (!uiReady) {
         uiReady = true;
         if (q->Applet::d->started && (appletsUiReady || applets.isEmpty()) && loadingApplets.isEmpty()) {
-            emit q->uiReadyChanged(true);
+            Q_EMIT q->uiReadyChanged(true);
         }
     }
 }
 
-void ContainmentPrivate::appletLoaded(Applet* applet)
+void ContainmentPrivate::appletLoaded(Applet *applet)
 {
     loadingApplets.remove(applet);
 
     if (loadingApplets.isEmpty() && !appletsUiReady) {
         appletsUiReady = true;
         if (q->Applet::d->started && uiReady) {
-            emit q->uiReadyChanged(true);
+            Q_EMIT q->uiReadyChanged(true);
         }
     }
 }
